pub fn is_editor_element(
tag: ExpandedName<'_, '_>,
editor_prefixes: &[String],
) -> boolExpand description
Check if an element belongs to an editor namespace (e.g., sodipodi:namedview).
pub fn is_editor_element(
tag: ExpandedName<'_, '_>,
editor_prefixes: &[String],
) -> boolCheck if an element belongs to an editor namespace (e.g., sodipodi:namedview).